@@ -16,6 +16,12 @@ case "${MODE}" in
     flake8 bleach/ ;;
   vendorverify)
     ./scripts/vendor_verify.sh ;;
+  docs)
+    tox -e docs ;;
+  format)
+    black --target-version=py36 bleach/*.py tests/ tests_website/ ;;
+  format-check)
+    black --target-version=py36 --check --diff bleach/*.py tests/ tests_website/ ;;
   *)
     echo "Unknown mode $MODE."
     exit 1
